@@ -1,7 +1,7 @@
 monotypic <- function(refl, nr.member = 1, reflist.type = c('Turboveg', 'EDIT'), write = FALSE, filename,  tv_home, ...) {
  reflist.type <- match.arg(reflist.type)	
  if(reflist.type=='Turboveg' & missing(tv_home)) tv_home <- tv.home()
- taxa <- load.taxlist(refl = refl, reflist.type=reflist.type , verbose = TRUE, ...)
+ taxa <- load.taxlist(refl = refl, reflist.type=reflist.type , detailed = TRUE, ...)
  names(taxa) <- TCS.replace(names(taxa))
  AG <- table(taxa$IsChildTaxonOfID)
  AG <- names(AG[AG == nr.member])
