@@ -1,6 +1,7 @@
 if(getRversion() >= "2.15.1")  utils::globalVariables(c("DoWritedbf"))
 
-tv.write <- function(x, site, name, cover=c('code','perc'), overwrite = FALSE, iconv="WINDOWS-1252", db, tvadmin=FALSE, ...) {
+tv.write <- function(x, site, db, name, cover=c('code','perc'), overwrite = FALSE, iconv="WINDOWS-1250", newTvAdmin = FALSE, ...) {
+  if(missing(db)) stop('Name of original database is missing.')
   cover <- match.arg(cover)
   if('veg' %in% class(x)) {
     X <- reShape.veg(x, ...)
@@ -18,8 +19,9 @@ tv.write <- function(x, site, name, cover=c('code','perc'), overwrite = FALSE, i
     X <- x
   }
 #  names(X)[2] <- 'SPECIES_NR'
-  if(!overwrite) if(file.exists(file.path(options('tv_home'), 'Data', name))) 
-    stop('Database ', name, ' already exists.')
+  if(!overwrite) 
+    if(file.exists(file.path(options('tv_home'), 'Data', name, 'tvhabita.dbf'))) 
+      stop('Database ', name, ' already exists.')
   site$DATE <- gsub('-','',site$DATE)
   for(i in names(site)) if(is.character(site[,i])) {
     site[is.na(site[,i]),i] <- ''
@@ -27,26 +29,32 @@ tv.write <- function(x, site, name, cover=c('code','perc'), overwrite = FALSE, i
   }
 
 ### Write
-  dir.create(file.path(options('tv_home'), 'Data', name), showWarnings = TRUE)
+  dir.create(file.path(options('tv_home'), 'Data', name), showWarnings = if(overwrite) FALSE else TRUE)
   write.dbf(site, file.path(options('tv_home'), 'Data', name, 'tvhabita.dbf'))
   write.dbf(X, file.path(options('tv_home'), 'Data', name, 'tvabund.dbf'))
+ # Remarks
+  remarks <- read.dbf(file.path(options('tv_home'), 'Data', db[1], 'remarks.dbf'), as.is=TRUE)
+  if(length(db) > 1) 
+    for(n in 2:length(db)) remarks <- rbind(remarks, read.dbf(file.path(options('tv_home'), 'Data', db[n], 'remarks.dbf'), as.is=TRUE))
+  remarks <- remarks[remarks$RELEVE_NR %in% site$RELEVE_NR,]
+  op <- options('warn')
+  options(warn=-1)
+  suppressWarnings(write.dbf(remarks, file.path(options('tv_home'), 'Data', name, 'remarks.dbf')))
+  options(op)
+ # TvAdmin
+  TvAdmin <- read.dbf(file.path(options('tv_home'), 'Data', db[1], 'TvAdmin.dbf'))
+  if(length(db) > 1) 
+    for(n in 2:length(db)) TvAdmin <- rbind(TvAdmin, read.dbf(file.path(options('tv_home'), 'Data', db[1], 'TvAdmin.dbf')))
+  TvAdmin <- TvAdmin[TvAdmin$RELEVE_NR %in% site$RELEVE_NR,]
+  TvAdmin$MOD_USER[is.na(TvAdmin$MOD_USER)] <- Sys.getenv('USER')
+#  TvAdmin$MOD_DATE[is.na(TvAdmin$MOD_DATE)] <- format(Sys.Date(), "%D")
+  write.dbf(TvAdmin, file.path(options('tv_home'), 'Data', name, 'TvAdmin.dbf'))
 
-  cat('\nTurboveg database', name, 'written to', file.path(options('tv_home'), 'Data', name))
+  if(!any(db == name)) file.copy(from = file.path(options('tv_home'), 'Data', db[1], 'tvwin.set'), to=file.path(options('tv_home'),'Data', name, 'tvwin.set'), overwrite = overwrite)
 
-if(!missing(db)) {
-  file.copy(from=file.path(options('tv_home'), 'Data', db, 'remarks.dbf'), 
-            to=file.path(options('tv_home'),'Data', name, 'remarks.dbf'), overwrite = overwrite)
-  file.copy(from=file.path(options('tv_home'), 'Data', db, 'TvAdmin.dbf'), 
-            to=file.path(options('tv_home'),'Data', name, 'TvAdmin.dbf'), overwrite = overwrite)
-  file.copy(from=file.path(options('tv_home'), 'Data', db, 'tvwin.set'), 
-            to=file.path(options('tv_home'),'Data', name, 'tvwin.set'), overwrite = overwrite)
+  cat('Turboveg database', name, 'written to', file.path(options('tv_home'), 'Data', name),'\n')
 
-} else {
-  file.copy(from=file.path(options('tv_home'), 'Data/taxatest/remarks.dbf'), 
-            to=file.path(options('tv_home'),'Data', name, 'remarks.dbf'), overwrite = overwrite)
-  cat("\n Please specify correct species list, dictionary and area when first opening the database in Turboveg. GUID's and remarks might be lost.\n")
- }
-if(tvadmin) {
+if(newTvAdmin) {
   # tvadmin <- read.dbf(file.path(options('tv_home'), 'Data', db, 'TvAdmin.dbf'))
   # RELEVE_NR,N,6,0  SOURCE_DB,C,38	GUID,C,38	CREAT_USER,C,25	CREAT_DATE,D	MOD_USER,C,25	MOD_DATE,D	NDFF_QUAL,N,1,0
   tvadmin <- data.frame(RELEVE_NR=site$RELEVE_NR, SOURCE_DB=db,	GUID=uuid(n=nrow(site)),	CREAT_USER=Sys.getenv('USER'), CREAT_DATE=Sys.Date(), MOD_USER=Sys.getenv('USER'),	MOD_DATE=Sys.Date(), NDFF_QUAL=as.integer(0))
